/*
** Module   : ContainerEntity.java
** Abstract : server side container widget parent class
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -JPRM-- ----------------Description-----------------
** 001 NVS 20051026  @23485 Created initial version.
** 002 GES 20060803  @28369 Some cleanup and refactoring.
** 003 SIY 20111101          Updated imports.
** 004 CA  20130222          Added NPE protection for cases when a widget is used before is 
**                           attached to a frame (after a CREATE WIDGET statement is used).
** 005 CA  20131115          Changes related to properly instantiate dynamic resources.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Server side container widget parent class.
 */
public class ContainerEntity
extends BaseEntity
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private ContainerConfig cc = null;
   
   /**
    * Constructor for use by sub-classes.
    *
    * @param   dynamic
    *          Flag indicating if this is a static or dynamic resource.
    * @param   cc
    *          Configuration container.
    */
   public ContainerEntity(boolean dynamic, ContainerConfig cc)
   {
      super(dynamic, cc);
      this.cc = cc;
   }
   
   /**
    * Gets the SCROLLABLE writeable attribute.
    *
    * @return   The current value of the SCROLLABLE attribute.
    */
   public logical isScrollable()
   {
      return new logical(cc.isScrollable());
   }

   /**
    * Sets the SCROLLABLE writeable attribute.
    *
    * @param    scroll
    *           The new value for the SCROLLABLE attribute.
    */
   public void setScrollable(logical scroll)
   {
      setScrollable(scroll.booleanValue());
   }

   /**
    * Sets the SCROLLABLE writeable attribute.
    *
    * @param    scroll
    *           The new value for the SCROLLABLE attribute.
    */
   public void setScrollable(boolean scroll)
   {
      cc.setScrollable(scroll);
      pushScreenDefinition();
   }
}
